@@ -41,7 +41,7 @@ load(
 
 ios_test_runner(
     name = "ios_x86_64_sim_runner",
-    device_type = "iPhone 8",
+    device_type = "iPhone Xs",
 )
 
 EOF
@@ -85,7 +85,7 @@ ios_application(
     bundle_id = "my.bundle.id",
     families = ["iphone"],
     infoplists = ["Info.plist"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     provisioning_profile = "@build_bazel_rules_apple//test/testdata/provisioning:integration_testing_ios.mobileprovision",
     deps = [":app_lib"],
 )
@@ -99,12 +99,15 @@ function create_ios_unit_tests() {
 
   cat > ios/pass_unit_test.m <<EOF
 #import <XCTest/XCTest.h>
+#import <XCTest/XCUIApplication.h>
 
 @interface PassingUnitTest : XCTestCase
 
 @end
 
-@implementation PassingUnitTest
+@implementation PassingUnitTest {
+  XCUIApplication *_app;
+}
 
 - (void)testPass {
   XCTAssertEqual(1, 1, @"should pass");
@@ -125,6 +128,11 @@ function create_ios_unit_tests() {
   XCTAssertEqualObjects([NSProcessInfo processInfo].environment[@"IMAGE_DIR"], @"/Project/My Tests/Images", @"should pass");
 }
 
+- (void)uiTestSymbols { 
+  // This function triggers https://github.com/google/xctestrunner/blob/7f8fc81b10c8d93f09f6fe38b2a3f37ba25336a6/test_runner/xctest_session.py#L382
+  _app = [[XCUIApplication alloc] init];
+}
+
 @end
 EOF
 
@@ -203,7 +211,7 @@ ios_unit_test(
     name = "PassingUnitTest",
     infoplists = ["PassUnitTest-Info.plist"],
     deps = [":pass_unit_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     env = test_env,
     runner = ":ios_x86_64_sim_runner",
 )
@@ -212,7 +220,7 @@ ios_unit_test(
     name = "PassingWithHost",
     infoplists = ["PassUnitTest-Info.plist"],
     deps = [":pass_unit_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     test_host = ":app",
     env = test_env,
     runner = ":ios_x86_64_sim_runner",
@@ -228,7 +236,7 @@ ios_unit_test(
     name = "PassingUnitSwiftTest",
     infoplists = ["PassUnitSwiftTest-Info.plist"],
     deps = [":pass_unit_swift_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     test_host = ":app",
     runner = ":ios_x86_64_sim_runner",
 )
@@ -242,7 +250,7 @@ ios_unit_test(
     name = 'FailingUnitTest',
     infoplists = ["FailUnitTest-Info.plist"],
     deps = [":fail_unit_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     runner = ":ios_x86_64_sim_runner",
 )
 
@@ -250,7 +258,7 @@ ios_unit_test(
     name = 'FailingWithHost',
     infoplists = ["FailUnitTest-Info.plist"],
     deps = [":fail_unit_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     test_host = ":app",
     runner = ":ios_x86_64_sim_runner",
 )
@@ -300,7 +308,7 @@ ios_unit_test(
     name = 'EnvUnitTest',
     infoplists = ["EnvUnitTest-Info.plist"],
     deps = [":env_unit_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     runner = ":ios_x86_64_sim_runner",
 )
 
@@ -308,13 +316,86 @@ ios_unit_test(
     name = 'EnvWithHost',
     infoplists = ["EnvUnitTest-Info.plist"],
     deps = [":env_unit_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     test_host = ":app",
     runner = ":ios_x86_64_sim_runner",
 )
 EOF
 }
 
+function create_ios_unit_make_var_test() {
+  if [[ ! -f ios/BUILD ]]; then
+    fail "create_sim_runners must be called first."
+  fi
+
+  cat > ios/make_var_unit_test.m <<EOF
+#import <XCTest/XCTest.h>
+#include <assert.h>
+#include <stdlib.h>
+
+@interface MakeVarUnitTest : XCTestCase
+
+@end
+
+@implementation MakeVarUnitTest
+
+- (void)testMakeVar {
+  XCTAssertEqualObjects([NSProcessInfo processInfo].environment[@"MY_MAKE_VAR"], @"$1", @"should pass");
+}
+
+@end
+EOF
+
+  cat >ios/MakeVarUnitTest-Info.plist <<EOF
+<plist version="1.0">
+<dict>
+        <key>CFBundleExecutable</key>
+        <string>MakeVarUnitTest</string>
+</dict>
+</plist>
+EOF
+
+  cat >> ios/BUILD <<EOF
+load("@bazel_skylib//rules:common_settings.bzl", "string_flag")
+
+string_flag(
+    name = "my_make_var",
+    build_setting_default = "",
+    make_variable = "MY_MAKE_VAR",
+)
+
+objc_library(
+    name = "make_var_unit_test_lib",
+    srcs = ["make_var_unit_test.m"],
+)
+
+ios_unit_test(
+    name = 'MakeVarUnitTest',
+    infoplists = ["MakeVarUnitTest-Info.plist"],
+    deps = [":make_var_unit_test_lib"],
+    minimum_os_version = "${MIN_OS_IOS}",
+    runner = ":ios_x86_64_sim_runner",
+    env = {
+        "MY_MAKE_VAR": "\$(MY_MAKE_VAR)",
+    },
+    toolchains = [":my_make_var"],
+)
+
+ios_unit_test(
+    name = 'MakeVarWithHost',
+    infoplists = ["MakeVarUnitTest-Info.plist"],
+    deps = [":make_var_unit_test_lib"],
+    minimum_os_version = "${MIN_OS_IOS}",
+    test_host = ":app",
+    runner = ":ios_x86_64_sim_runner",
+    env = {
+        "MY_MAKE_VAR": "\$(MY_MAKE_VAR)",
+    },
+    toolchains = [":my_make_var"],
+)
+EOF
+}
+
 function create_ios_unit_argtest() {
   if [[ ! -f ios/BUILD ]]; then
     fail "create_sim_runners must be called first."
@@ -360,7 +441,7 @@ ios_unit_test(
     name = 'ArgUnitTest',
     infoplists = ["ArgUnitTest-Info.plist"],
     deps = [":arg_unit_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     runner = ":ios_x86_64_sim_runner",
     args = [
       "--command_line_args=--flag",
@@ -378,20 +459,27 @@ function create_ios_unit_tests_test_filter() {
   cat > ios/test_filter_unit_test.m <<EOF
 #import <XCTest/XCTest.h>
 #import <XCTest/XCUIApplication.h>
+
 @interface TestFilterUnitTest : XCTestCase
+
 @end
+
 @implementation TestFilterUnitTest {
   XCUIApplication *_app;
 }
+
 - (void)testPass {
   XCTAssertEqual(1, 1, @"should pass");
 }
+
 - (void)testPass2 {
   XCTAssertEqual(1, 1, @"should pass");
 }
+
 - (void)testPass3 {
   XCTAssertEqual(1, 1, @"should pass");
 }
+
 @end
 EOF
 
@@ -409,11 +497,12 @@ objc_library(
     name = "test_filter_unit_test_lib",
     srcs = ["test_filter_unit_test.m"],
 )
+
 ios_unit_test(
     name = "TestFilterUnitTest",
     infoplists = ["TestFilterUnitTest-Info.plist"],
     deps = [":test_filter_unit_test_lib"],
-    minimum_os_version = "9.0",
+    minimum_os_version = "${MIN_OS_IOS}",
     test_host = ":app",
     runner = ":ios_x86_64_sim_runner",
     test_filter = "$1",
@@ -421,6 +510,60 @@ ios_unit_test(
 EOF
 }
 
+function create_ios_unit_main_thread_checker_tests() { 
+  cat > ios/main_thread_checker_violation.swift <<EOF
+import XCTest
+
+class MainThreadCheckerViolationTest : XCTestCase {
+  func testTriggerMainThreadChecker() {
+        let expectation = self.expectation(description: "Background operation")
+
+        DispatchQueue.global().async {
+            // This will trigger the Main Thread Checker because we are 
+            // trying to update the UI from a background thread.
+            let label = UILabel()
+            label.text = "Test"
+
+            expectation.fulfill()
+        }
+
+        waitForExpectations(timeout: 5) { (error) in
+            if let error = error {
+                XCTFail("waitForExpectations errored: \(error)")
+            }
+            
+        }
+    }
+}
+EOF
+
+  cat > ios/MainThreadCheckerViolationTest-Info.plist <<EOF
+<plist version="1.0">
+<dict>
+        <key>CFBundleExecutable</key>
+        <string>MainThreadCheckerViolationTest</string>
+</dict>
+</plist>
+EOF
+
+  cat >> ios/BUILD <<EOF
+swift_library(
+    name = "main_thread_checker_violation_test_lib",
+    testonly = True,
+    srcs = ["main_thread_checker_violation.swift"],
+)
+
+ios_unit_test(
+    name = "MainThreadCheckerViolationTest",
+    infoplists = ["MainThreadCheckerViolationTest-Info.plist"],
+    deps = [":main_thread_checker_violation_test_lib"],
+    minimum_os_version = "${MIN_OS_IOS}",
+    test_host = ":app",
+    runner = ":ios_x86_64_sim_runner",
+)
+EOF
+}
+
 function do_ios_test() {
   do_test ios "--test_output=all" "--spawn_strategy=local" "$@"
 }
@@ -572,6 +715,40 @@ function test_ios_unit_test_with_host_with_env() {
   expect_log "Test Suite 'EnvUnitTest' passed"
 }
 
+function test_ios_unit_test_with_make_var_empty() {
+  create_sim_runners
+  create_ios_unit_make_var_test ""
+  do_ios_test //ios:MakeVarUnitTest || fail "should pass"
+
+  expect_log "Test Suite 'MakeVarUnitTest' passed"
+}
+
+function test_ios_unit_test_with_make_var_set() {
+  create_sim_runners
+  create_ios_unit_make_var_test MAKE_VAR_VALUE1
+  do_ios_test --//ios:my_make_var=MAKE_VAR_VALUE1 //ios:MakeVarUnitTest || fail "should pass"
+
+  expect_log "Test Suite 'MakeVarUnitTest' passed"
+}
+
+function test_ios_unit_test_with_host_with_make_var_empty() {
+  create_sim_runners
+  create_test_host_app
+  create_ios_unit_make_var_test ""
+  do_ios_test //ios:MakeVarWithHost || fail "should pass"
+
+  expect_log "Test Suite 'MakeVarUnitTest' passed"
+}
+
+function test_ios_unit_test_with_host_with_make_var_set() {
+  create_sim_runners
+  create_test_host_app
+  create_ios_unit_make_var_test MAKE_VAR_VALUE1
+  do_ios_test --//ios:my_make_var=MAKE_VAR_VALUE1 //ios:MakeVarWithHost || fail "should pass"
+
+  expect_log "Test Suite 'MakeVarUnitTest' passed"
+}
+
 function test_ios_unit_simulator_id() {
   create_sim_runners
   create_ios_unit_tests
@@ -624,6 +801,16 @@ function test_ios_unit_test_with_multi_equal_env() {
   expect_log "Test Suite 'EnvUnitTest' passed"
 }
 
+function test_ios_unit_test_pass_asan() {
+  create_sim_runners
+  create_ios_unit_tests
+  do_ios_test --features=asan //ios:PassingUnitTest || fail "should pass"
+
+  expect_log "Test Suite 'PassingUnitTest' passed"
+  expect_log "Test Suite 'PassingUnitTest.xctest' passed"
+  expect_log "Executed 4 tests, with 0 failures"
+}
+
 function test_with_test_filter_build_attribute() {
   create_sim_runners
   create_test_host_app
@@ -705,4 +892,26 @@ function test_ios_unit_test_with_build_attribute_and_test_env_filters() {
   expect_log "Executed 2 tests, with 0 failures"
 }
 
+function test_ios_unit_test_pass_main_thread_checker_without_crash_on_report_pass() {
+  create_sim_runners
+  create_test_host_app
+  create_ios_unit_main_thread_checker_tests
+  do_ios_test --features=apple.include_main_thread_checker //ios:MainThreadCheckerViolationTest || fail "should pass"
+
+  expect_log "Test Suite 'MainThreadCheckerViolationTest' passed"
+  expect_log "Test Suite 'MainThreadCheckerViolationTest.xctest' passed"
+  expect_log "Executed 1 test, with 0 failures"
+}
+
+function test_ios_unit_test_pass_main_thread_checker_with_crash_on_report_fail() {
+  create_sim_runners
+  create_test_host_app
+  create_ios_unit_main_thread_checker_tests
+  ! do_ios_test --features=apple.include_main_thread_checker --features=apple.fail_on_main_thread_checker //ios:MainThreadCheckerViolationTest || fail "should fail"
+
+  expect_log "Test Suite 'MainThreadCheckerViolationTest' failed"
+  expect_log "Test Suite 'MainThreadCheckerViolationTest.xctest' failed"
+  expect_log "Executed 1 test, with 1 failure"
+}
+
 run_suite "ios_unit_test with iOS test runner bundling tests"
